@@ -3,14 +3,14 @@ from typing import List, Optional
 from pydantic import BaseModel, Field, validator
 
 
-class NCVSamples(BaseModel):
-    """Data points for NCV plots.
+class ZscoreSamples(BaseModel):
+    """Data points for Zscore plots.
 
     Samples within this model will be part of the same series in a plot.
 
     The x-axis is of type int because:
-        NCV plots for a batch have samples on the x-axis.
-        NCV plot for a sample have chromosome abnormalities (13 18 21)"""
+        Zscore plots for a batch have samples on the x-axis.
+        Zscore plot for a sample have chromosome abnormalities (13 18 21)"""
 
     count: Optional[int]
     x_axis: Optional[List[int]]
@@ -34,14 +34,14 @@ class NCVSamples(BaseModel):
         validate_assignment = True
 
 
-class NCV131821(BaseModel):
+class Zscore131821(BaseModel):
     """Model for samples classified as normal chromosome 13, 18, 21.
 
     Samples are grouped by chromosome."""
 
-    ncv_13: NCVSamples = Field(..., alias="13")
-    ncv_18: NCVSamples = Field(..., alias="18")
-    ncv_21: NCVSamples = Field(..., alias="21")
+    chr_13: ZscoreSamples = Field(..., alias="13")
+    chr_18: ZscoreSamples = Field(..., alias="18")
+    chr_21: ZscoreSamples = Field(..., alias="21")
 
     class Config:
         allow_population_by_field_name = True
